@@ -10,10 +10,10 @@ from trytond.transaction import Transaction
 from trytond.tools import grouped_slice
 
 __all__ = ['Invoice', 'InvoiceLine']
-__metaclass__ = PoolMeta
 
 
 class Invoice:
+    __metaclass__ = PoolMeta
     __name__ = 'account.invoice'
     agent = fields.Many2One('commission.agent', 'Commission Agent',
         domain=[
@@ -105,6 +105,7 @@ class Invoice:
 
 
 class InvoiceLine:
+    __metaclass__ = PoolMeta
     __name__ = 'account.invoice.line'
     principal = fields.Many2One('commission.agent', 'Commission Principal',
         domain=[
@@ -114,10 +115,8 @@ class InvoiceLine:
             ],
         states={
             'invisible': If(Bool(Eval('_parent_invoice')),
-                Eval('_parent_invoice', {}).get('type').in_(
-                    ['in_invoice', 'in_credit_note']),
-                Eval('invoice_type').in_(
-                    ['in_invoice', 'in_credit_note'])),
+                Eval('_parent_invoice', {}).get('type') == 'in',
+                Eval('invoice_type') == 'in'),
             }, depends=['invoice_type', 'company'])
     commissions = fields.One2Many('commission', 'origin', 'Commissions',
         readonly=True,
